library(lme4)
library(MBESS)
library(car)
library(MASS)
library(boot)
library(QuantPsyc)
library(Hmisc)
library(reshape)
library(brglm)
library(RODBC)
library(ez)
library(sciplot)
library(psych)
library(multilevel)
library(car)
library(pequod)
library(coin)
library(vioplot)

setwd("/Users/willgervais/Documents/Google Drive/Secrets/Research/Accepted/PLOS Atheist immorality")

#############################
#######Serial Murder ########
#############################


FullS <- read.table("Exp1.csv", header=T, sep=",")
summary(FullS)
FullS$Religious <- ifelse(FullS$RelID < 6.1, 
c("Religious"), c("Nonreligious")) 
CleanS <- FullS[ which(FullS$PrezCatch=='0'),]
CleanS$Prejudice <- ifelse(CleanS$Topic=="4",1,0)
CleanS$TargNum <- ifelse(CleanS$Target=="Atheist", 1, 0)
summary(CleanS)

describe(CleanS$Age)
describe(CleanS$Politics)
describe(CleanS$SES)
describe(CleanS$BiG100)


table(FullS$PrezCatch)
TopicS <- table(CleanS$Topic)
prop.table(TopicS)

ErrorsS <- table(CleanS$Error, CleanS$Target)
prop.table(ErrorsS, 2)

bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE, res=1200,
    col=NULL, angle=NULL, density=NULL, main="Serial Killer",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=CleanS, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)
     
OverallS <- table(CleanS$Target, CleanS$Error) 
ftable(OverallS)
summary(OverallS)


###Atheist vs Religious

AthTargS.lm <- glm(Error~ TargNum, family=binomial, data=CleanS)
summary(AthTargS.lm)
exp(coef(AthTargS.lm)) # exponentiated coefficients
exp(confint(AthTargS.lm)) # 95% CI for exponentiated coefficients

###Pairwise Comparisons

AthBuddhistS <- CleanS[ which(CleanS$Target=='Atheist' | CleanS$Target=='Buddhist'),]
summary(AthBuddhist)
AthChristianS <- CleanS[ which(CleanS$Target=='Atheist' | CleanS$Target=='Christian'),]
summary(AthChristianS)
AthJewishS <- CleanS[ which(CleanS$Target=='Atheist' | CleanS$Target=='Jewish'),]
summary(AthJewishS)
AthMuslimS <- CleanS[ which(CleanS$Target=='Atheist' | CleanS$Target=='Muslim'),]
summary(AthMuslimS)
AthHinduS <- CleanS[ which(CleanS$Target=='Atheist' | CleanS$Target=='Hindu'),]
summary(AthHinduS)


BuddhistS.lm <- glm(Error~ TargNum, family=binomial, data=AthBuddhistS)
summary(BuddhistS.lm)
exp(coef(BuddhistS.lm)) # exponentiated coefficients
exp(confint(BuddhistS.lm)) # 95% CI for exponentiated coefficients

HinduS.lm <- glm(Error~ TargNum, family=binomial, data=AthHinduS)
summary(HinduS.lm)
exp(coef(HinduS.lm)) # exponentiated coefficients
exp(confint(HinduS.lm)) # 95% CI for exponentiated coefficients

JewishS.lm <- glm(Error~ TargNum, family=binomial, data=AthJewishS)
summary(JewishS.lm)
exp(coef(JewishS.lm)) # exponentiated coefficients
exp(confint(JewishS.lm)) # 95% CI for exponentiated coefficients

MuslimS.lm <- glm(Error~ TargNum, family=binomial, data=AthMuslimS)
summary(MuslimS.lm)
exp(coef(MuslimS.lm)) # exponentiated coefficients
exp(confint(MuslimS.lm)) # 95% CI for exponentiated coefficients

ChristianS.lm <- glm(Error~ TargNum, family=binomial, data=AthChristianS)
summary(ChristianS.lm)
exp(coef(ChristianS.lm)) # exponentiated coefficients
exp(confint(ChristianS.lm)) # 95% CI for exponentiated coefficients




###Check Just Atheist Target###

AthS <- CleanS[ which(CleanS$Target=='Atheist'),]
AthS$zBiG100 <- scale(AthS$BiG100, scale=T, center=T)
summary(AthS)

BiGS.lm <- glm(Error~ zBiG100, family=binomial, data=AthS)
summary(BiGS.lm)
exp(coef(BiGS.lm)) # exponentiated coefficients
exp(confint(BiGS.lm)) # 95% CI for exponentiated coefficients



##################################################
### Incest RelGroups##############################
##################################################


FullI <- read.table("Exp2.csv", header=T, sep=",")
FullI$Religious <- ifelse(FullI$RelID < 6.1, 
c("Religious"), c("Nonreligious")) 
CleanI <- FullI[ which(FullI$PrezCatch=='0'),]
summary(CleanI)

describe(CleanI$Age)
describe(CleanI$Politics)
describe(CleanI$SES)
describe(CleanI$BiG100)


table(FullI$PrezCatch)

bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE,
    col=NULL, angle=NULL, density=NULL, main="Incest",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=CleanI, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)
     
Overall <- table(CleanI$Target, CleanI$Error) 
ftable(Overall)
summary(Overall)

ErrorsI <- table(CleanI$Error, CleanI$Target)
prop.table(ErrorsI, 2)

###Atheist vs Religious

Overall.lm <- glm(Error~ TargNum, family=binomial, data=CleanI)
summary(Overall.lm)
exp(coef(Overall.lm)) # exponentiated coefficients
exp(confint(Overall.lm)) # 95% CI for exponentiated coefficients

###Pairwise Comparisons

AthBuddhist <- CleanI[ which(CleanI$Target=='Atheist' | CleanI$Target=='Buddhist'),]
summary(AthBuddhist)
AthChristian <- CleanI[ which(CleanI$Target=='Atheist' | CleanI$Target=='Christian'),]
summary(AthChristian)
AthJewish <- CleanI[ which(CleanI$Target=='Atheist' | CleanI$Target=='Jewish'),]
summary(AthJewish)
AthMuslim <- CleanI[ which(CleanI$Target=='Atheist' | CleanI$Target=='Muslim'),]
summary(AthMuslim)
AthHindu <- CleanI[ which(CleanI$Target=='Atheist' | CleanI$Target=='Hindu'),]
summary(AthHindu)


Buddhist.lm <- glm(Error~ TargNum, family=binomial, data=AthBuddhist)
summary(Buddhist.lm)
exp(coef(Buddhist.lm)) # exponentiated coefficients
exp(confint(Buddhist.lm)) # 95% CI for exponentiated coefficients

Hindu.lm <- glm(Error~ TargNum, family=binomial, data=AthHindu)
summary(Hindu.lm)
exp(coef(Hindu.lm)) # exponentiated coefficients
exp(confint(Hindu.lm)) # 95% CI for exponentiated coefficients

Jewish.lm <- glm(Error~ TargNum, family=binomial, data=AthJewish)
summary(Jewish.lm)
exp(coef(Jewish.lm)) # exponentiated coefficients
exp(confint(Jewish.lm)) # 95% CI for exponentiated coefficients

Muslim.lm <- glm(Error~ TargNum, family=binomial, data=AthMuslim)
summary(Muslim.lm)
exp(coef(Muslim.lm)) # exponentiated coefficients
exp(confint(Muslim.lm)) # 95% CI for exponentiated coefficients

Christian.lm <- glm(Error~ TargNum, family=binomial, data=AthChristian)
summary(Christian.lm)
exp(coef(Christian.lm)) # exponentiated coefficients
exp(confint(Christian.lm)) # 95% CI for exponentiated coefficients




###Check Just Atheist Target###

Ath <- CleanI[ which(CleanI$Target=='Atheist'),]
Ath$zBiG100 <- scale(Ath$BiG100, scale=T, center=T)
summary(Ath)

BiG.lm <- glm(Error~ zBiG100, family=binomial, data=Ath)
summary(BiG.lm)
exp(coef(BiG.lm)) # exponentiated coefficients
exp(confint(BiG.lm)) # 95% CI for exponentiated coefficients




##################################################
### Chicken EthGroups##############################
##################################################


FullC <- read.table("Exp3.csv", header=T, sep=",")
FullC$Religious <- ifelse(FullC$RelID < 6.1, 
c("Religious"), c("Nonreligious")) 
CleanC <- FullC[ which(FullC$PrezCatch=='0'),]
summary(CleanC)

describe(CleanC$Age)
describe(CleanC$Politics)
describe(CleanC$SES)
describe(CleanC$BiG100)


table(FullC$PrezCatch)

CleanC$Target <- factor(CleanC$Target, levels = c("Atheist", 
"Asian", "Black", "Hispanic", "Native", "White"),
labels = c("Atheist", "Asian", "Black", "Hispanic", "Native Am", "White")) 

bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE,
    col=NULL, angle=NULL, density=NULL, main="Chicken Lover",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=CleanC, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)
          
Overall <- table(CleanC$Target, CleanC$Error) 
ftable(Overall)
summary(Overall)


ErrorsC <- table(CleanC$Error, CleanC$Target)
prop.table(ErrorsC, 2)


###Atheist vs Others

Overall.lm <- glm(Error~ TargNum, family=binomial, data=CleanC)
summary(Overall.lm)
exp(coef(Overall.lm)) # exponentiated coefficients
exp(confint(Overall.lm)) # 95% CI for exponentiated coefficients

###Pairwise Comparisons

AthAsian <- CleanC[ which(CleanC$Target=='Atheist' | CleanC$Target=='Asian'),]
summary(AthAsian)
AthWhite <- CleanC[ which(CleanC$Target=='Atheist' | CleanC$Target=='White'),]
summary(AthWhite)
AthBlack <- CleanC[ which(CleanC$Target=='Atheist' | CleanC$Target=='Black'),]
summary(AthBlack)
AthHispanic <- CleanC[ which(CleanC$Target=='Atheist' | CleanC$Target=='Hispanic'),]
summary(AthHispanic)
AthNativeAmerican <- CleanC[ which(CleanC$Target=='Atheist' | CleanC$Target=='Native Am'),]
summary(AthNativeAmerican)


Asian.lm <- glm(Error~ TargNum, family=binomial, data=AthAsian)
summary(Asian.lm)
exp(coef(Asian.lm)) # exponentiated coefficients
exp(confint(Asian.lm)) # 95% CI for exponentiated coefficients

NativeAmerican.lm <- glm(Error~ TargNum, family=binomial, data=AthNativeAmerican)
summary(NativeAmerican.lm)
exp(coef(NativeAmerican.lm)) # exponentiated coefficients
exp(confint(NativeAmerican.lm)) # 95% CI for exponentiated coefficients

Black.lm <- glm(Error~ TargNum, family=binomial, data=AthBlack)
summary(Black.lm)
exp(coef(Black.lm)) # exponentiated coefficients
exp(confint(Black.lm)) # 95% CI for exponentiated coefficients

Hispanic.lm <- glm(Error~ TargNum, family=binomial, data=AthHispanic)
summary(Hispanic.lm)
exp(coef(Hispanic.lm)) # exponentiated coefficients
exp(confint(Hispanic.lm)) # 95% CI for exponentiated coefficients

White.lm <- glm(Error~ TargNum, family=binomial, data=AthWhite)
summary(White.lm)
exp(coef(White.lm)) # exponentiated coefficients
exp(confint(White.lm)) # 95% CI for exponentiated coefficients



##Reviewer Query: Do ethnic groups actually differ?

EthnicGroups <- CleanC[ which(CleanC$Target !='Atheist' ),]
summary(EthnicGroups)

EthTab <- table(EthnicGroups$Error, EthnicGroups$Target) 
EthTab 

fisher.test(EthTab)





###Check Just Atheist Target###

AthC <- CleanC[ which(CleanC$Target=='Atheist'),]
AthC$zBiG100 <- scale(AthC$BiG100, scale=T, center=T)
summary(AthC)

BiG.lm <- glm(Error~ zBiG100, family=binomial, data=AthC)
summary(BiG.lm)
exp(coef(BiG.lm)) # exponentiated coefficients
exp(confint(BiG.lm)) # 95% CI for exponentiated coefficients


##################################################
###5 found AthGay#################################
##################################################


Moral <- read.table("Exp4.csv", header=T, sep=",")
Moral$Religious <- ifelse(Moral$RelID < 6.1, 
c("Religious"), c("Nonreligious")) 
Moral$AthTarg <- ifelse(Moral$Target == "Atheist", 1, 0)
summary(Moral)


describe(Moral$Age)
describe(Moral$Politics)
describe(Moral$SES)
describe(Moral$BiG100)




bargraph.CI(x.factor=Condition, response=Error, group=Target, split=FALSE,
    col=NULL, angle=NULL, density=NULL,
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=Moral, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)


###Overall Atheist###


Ath.lm <- glm(Error~ TargNum, family=binomial, data=Moral)
summary(Ath.lm)
exp(coef(Ath.lm)) # exponentiated coefficients
exp(confint(Ath.lm)) # 95% CI for exponentiated coefficients

AthTarg <- Moral[ which(Moral$Target=='Atheist'),]
GayTarg <- Moral[ which(Moral$Target=='Gay'),]

Ath.table <- table(AthTarg$Condition, AthTarg$Error)
prop.table(Ath.table, 1)


Gay.table <- table(GayTarg$Condition, GayTarg$Error)
prop.table(Gay.table, 1)




####AthGay Comparisons###

Full5 <- Moral

Harm <- Full5[ which(Full5$Condition=='Harm'),]
Fair <- Full5[ which(Full5$Condition=='Fair'),]
Ingroup <- Full5[ which(Full5$Condition=='Ingroup'),]
Authority <- Full5[ which(Full5$Condition=='Authority'),]
Purity <- Full5[ which(Full5$Condition=='Purity'),]




Harm.lm <- glm(Error~ TargNum, family=binomial, data=Harm)
summary(Harm.lm)
exp(coef(Harm.lm)) # exponentiated coefficients
exp(confint(Harm.lm)) # 95% CI for exponentiated coefficients

Fair.lm <- brglm(Error~ TargNum, family=binomial, data=Fair)
summary(Fair.lm)
exp(coef(Fair.lm)) # exponentiated coefficients
exp(confint(Fair.lm)) # 95% CI for exponentiated coefficients



Ingroup.lm <- glm(Error~ TargNum, family=binomial, data=Ingroup)
summary(Ingroup.lm)
exp(coef(Ingroup.lm)) # exponentiated coefficients
exp(confint(Ingroup.lm)) # 95% CI for exponentiated coefficients

Authority.lm <- glm(Error~ TargNum, family=binomial, data=Authority)
summary(Authority.lm)
exp(coef(Authority.lm)) # exponentiated coefficients
exp(confint(Authority.lm)) # 95% CI for exponentiated coefficients

Purity.lm <- brglm(Error~ TargNum, family=binomial, data=Purity)
summary(Purity.lm)
exp(coef(Purity.lm)) # exponentiated coefficients
exp(confint(Purity.lm)) # 95% CI for exponentiated coefficients



####Atheist prediction with politics, religion###

FullAth <- Moral[ which(Moral$Target=='Atheist'),]
FullAth$zBiG100 <- scale(FullAth$BiG100, scale=T, center=T)
FullAth$zPolitics <- scale(FullAth$Politics, scale=T, center=T)

HarmAth <- FullAth[ which(FullAth$Condition=='Harm'),]
FairAth <- FullAth[ which(FullAth$Condition=='Fair'),]
IngroupAth <- FullAth[ which(FullAth$Condition=='Ingroup'),]
AuthorityAth <- FullAth[ which(FullAth$Condition=='Authority'),]
PurityAth <- FullAth[ which(FullAth$Condition=='Purity'),]







HarmAth.lm <- glm(Error~ zBiG100 + Politics, family=binomial, data=HarmAth)
summary(HarmAth.lm)
exp(coef(HarmAth.lm)) # exponentiated coefficients
exp(confint(HarmAth.lm)) # 95% CI for exponentiated coefficients

FairAth.lm <- glm(Error~ zBiG100 + Politics, family=binomial, data=FairAth)
summary(FairAth.lm)
exp(coef(FairAth.lm)) # exponentiated coefficients
exp(confint(FairAth.lm)) # 95% CI for exponentiated coefficients

IngroupAth.lm <- glm(Error~ zBiG100 + Politics, family=binomial, data=IngroupAth)
summary(IngroupAth.lm)
exp(coef(IngroupAth.lm)) # exponentiated coefficients
exp(confint(IngroupAth.lm)) # 95% CI for exponentiated coefficients

AuthorityAth.lm <- glm(Error~  zBiG100 + Politics, family=binomial, data=AuthorityAth)
summary(AuthorityAth.lm)
exp(coef(AuthorityAth.lm)) # exponentiated coefficients
exp(confint(AuthorityAth.lm)) # 95% CI for exponentiated coefficients


PurityAth.lm <- glm(Error~ zBiG100 + Politics, family=binomial, data=PurityAth)
summary(PurityAth.lm)
exp(coef(PurityAth.lm)) # exponentiated coefficients
exp(confint(PurityAth.lm)) # 95% CI for exponentiated coefficients


HarmAth.lm <- glm(Error~ Politics , family=binomial, data=HarmAth)
summary(HarmAth.lm)
exp(coef(HarmAth.lm)) # exponentiated coefficients
exp(confint(HarmAth.lm)) # 95% CI for exponentiated coefficients

FairAth.lm <- glm(Error~ Politics , family=binomial, data=FairAth)
summary(FairAth.lm)
exp(coef(FairAth.lm)) # exponentiated coefficients
exp(confint(FairAth.lm)) # 95% CI for exponentiated coefficients

IngroupAth.lm <- glm(Error~ Politics, family=binomial, data=IngroupAth)
summary(IngroupAth.lm)
exp(coef(IngroupAth.lm)) # exponentiated coefficients
exp(confint(IngroupAth.lm)) # 95% CI for exponentiated coefficients

AuthorityAth.lm <- glm(Error~ Politics , family=binomial, data=AuthorityAth)
summary(AuthorityAth.lm)
exp(coef(AuthorityAth.lm)) # exponentiated coefficients
exp(confint(AuthorityAth.lm)) # 95% CI for exponentiated coefficients


PurityAth.lm <- glm(Error~ Politics , family=binomial, data=PurityAth)
summary(PurityAth.lm)
exp(coef(PurityAth.lm)) # exponentiated coefficients
exp(confint(PurityAth.lm)) # 95% CI for exponentiated coefficients











#################Compound graph

par(mfrow=c(3,1))
bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE, family= "sans",
    col=c("firebrick3", "steelblue1", "steelblue1", "steelblue1", "steelblue1", "steelblue1"), angle=NULL, density=NULL, main="A: Serial Killer",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, .8), xpd=FALSE, data=CleanS, subset=NULL, 
     ylab='Error Rate', cex.lab=1.3, cex.axis=1.2,  cex.main=1.4)
abline(h=0, lty=1)
bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE, family= "sans",
    col=c("firebrick3", "steelblue1", "steelblue1", "steelblue1", "steelblue1", "steelblue1"), angle=NULL, density=NULL, main="B: Incest",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, .8), xpd=FALSE, data=CleanI, subset=NULL, 
     ylab='Error Rate', cex.lab=1.3, cex.axis=1.2,  cex.main=1.4)
abline(h=0, lty=1)
bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE,family= "sans",
    col=c("firebrick3", "steelblue1", "steelblue1", "steelblue1", "steelblue1", "steelblue1"), angle=NULL, density=NULL, main="C: Chicken",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, .8), xpd=FALSE, data=CleanC, subset=NULL, 
     ylab='Error Rate', cex.lab=1.3, cex.axis=1.2,  cex.main=1.4)
abline(h=0, lty=1)


     
     
     



###########################
######Community 2 by 2 ####
###########################


FullCommunity <- read.table("Community22.csv", header=T, sep=",")
summary(FullCommunity)


CleanCommunity <- FullCommunity[ which(FullCommunity$PrezCatch=='0'),]


summary(CleanCommunity)


describe(CleanCommunity$Age)

table(FullCommunity$PrezCatch)

GendTab <- table(CleanCommunity$Sex)
prop.table(GendTab)

bargraph.CI(x.factor=Belief, response=Error, group=Community, split=FALSE,
    col=NULL, angle=NULL, density=NULL, main="Moral Community",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=CleanCommunity, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)
     
     

AthTargCommunity.lm <- glm(Error~ BelCode*ComCode, family=binomial, data=CleanCommunity)
summary(AthTargCommunity.lm)
exp(coef(AthTargCommunity.lm)) # exponentiated coefficients
exp(confint(AthTargCommunity.lm)) # 95% CI for exponentiated coefficients



Belief22.lm <- glm(Error~ BelCode, family=binomial, data=CleanCommunity)
summary(Belief22.lm)
exp(coef(Belief22.lm)) # exponentiated coefficients
exp(confint(Belief22.lm)) # 95% CI for exponentiated coefficients


Community22.lm <- glm(Error~ ComCode, family=binomial, data=CleanCommunity)
summary(Community22.lm)
exp(coef(Community22.lm)) # exponentiated coefficients
exp(confint(Community22.lm)) # 95% CI for exponentiated coefficients






###########################################
##########Check just atheists Aggregate####
###########################################



AthS <- CleanS[ which(CleanS$RelID=='8' & CleanS$BiG100 == "0"
), ]
myvars <- c("TargNum", "Error")
AthS <- AthS[myvars]
AthS$Study <- 1
summary(AthS)

AthMoral <- Moral[ which(Moral$RelID=='8' & Moral$BiG100 == "0"
), ]
myvars <- c("TargNum", "Error")
AthMoral <- AthMoral[myvars]
AthMoral$Study <- 4
summary(AthMoral)

AthI <- CleanI[ which(CleanI$RelID=='8' & CleanI$BiG100 == "0"
), ]
myvars <- c("TargNum", "Error")
AthI <- AthI[myvars]
AthI$Study <- 2
summary(AthI)

AthC <- CleanC[ which(CleanC$RelID=='8' & CleanC$BiG100 == "0"
), ]
myvars <- c("TargNum", "Error")
AthC <- AthC[myvars]
AthC$Study <- 3
summary(AthC)






AtheistsID <- rbind(AthS, AthMoral, AthI, AthC)
summary(AtheistsID)

describe(AtheistsID)

table(AtheistsID$TargNum)

#dummy codes

AtheistsID$Dummy1 <- ifelse(AtheistsID$Study == 1, 
1, 0) 
AtheistsID$Dummy2 <- ifelse(AtheistsID$Study == 2, 
1, 0) 
AtheistsID$Dummy3 <- ifelse(AtheistsID$Study == 3, 
1, 0) 


AtheistsID.lm <- glm(Error~ TargNum + Dummy1 + Dummy2 + Dummy3, family=binomial, data=AtheistsID)
summary(AtheistsID.lm)
exp(coef(AtheistsID.lm)) # exponentiated coefficients
exp(confint(AtheistsID.lm)) # 95% CI for exponentiated coefficients





###################################
#####Overall Demographics##########
###################################

CleanS$Sex <- CleanS$Gender-1

CleanC$Sex <- CleanC$Gender

myvars <- c("RelID", "BiG100", "TargNum", "Error", "Politics", "EthID", "Age" , "Sex", "SES")

CleanSDem <- CleanS[myvars]
summary(CleanSDem)



myvars <- c("RelID", "BiG100", "TargNum", "Error", "Politics", "EthID", "Age" , "Sex",  "SES")

CleanIDem <- CleanI[myvars]
summary(CleanIDem)



myvars <- c("RelID", "BiG100", "TargNum", "Error", "Politics", "EthID", "Age" , "Sex", "SES", )
CleanCDem <- CleanC[myvars]
summary(CleanCDem)



myvars <- c("RelID", "BiG100", "TargNum", "Error", "Politics", "EthID", "Age" , "Sex", "SES")
MoralDem <- Moral[myvars]
summary(MoralDem)




OverallRel <- rbind(CleanSDem, MoralDem, CleanIDem, CleanCDem)
summary(OverallRel)


describe(OverallRel$Age)
describe(OverallRel$BiG100)
describe(OverallRel$SES)
describe(OverallRel$Politics)

RelID <- table(OverallRel$Religion)
prop.table(RelID)



OverallRel$Ethnicity <- factor(OverallRel$EthID, levels = c( 
"1", "2", "3", "4", "5","6","7"),
labels = c('White/Caucasian','African American','Hispanic','N. American','Asian', 'Mixed' ,'Other'))


OverallRel$Religion <- factor(OverallRel$RelID, levels = c("0", 
"1", "2", "3", "4", "5","6","7","8","9"),
labels = c('Other','Catholic','Baptist','Other Christian','Buddhist', 'Muslim' ,'Jewish', 'None', 'Atheist', 'Agnostic'))


RelID <- table(OverallRel$Religion)
prop.table(RelID)

EthIDTab <- table(OverallRel$Ethnicity)
prop.table(EthIDTab)


slices <- c((12.7+7.5+16.9), 2.3,.5, 1.9, 12.7, 21.7, 21.4, 2)
lbls <- c("Christian", "Buddhist", "Muslim", "Jewish", "None","Atheist","Agnostic", "Other")
pct <- round(slices/sum(slices)*100)
lbls <- paste(lbls, pct) # add percents to labels 
lbls <- paste(lbls,"%",sep="") 
pie(slices, labels = lbls, col=rainbow(length(lbls)), main="N = 946")

lbls <- paste(names(RelID), "\n", RelID, sep="")
pie(RelID, labels = lbls)

hist(OverallRel$Politics, main="Political Attitudes", xlab= "1 (Very Liberal) - 7 (Very Conservative)")

d <- density(OverallRel$BiG100, na.rm=TRUE)
plot(d, main="Belief in God", xlim= c(1, 99))
polygon(d, col="grey", border="black")


d <- density(OverallRel$Politics, na.rm=TRUE)
plot(d, main="Political Attitudes", xlim= c(1, 7))
polygon(d, col="grey", border="black")




###Study by Study Demographics###


##Study1

CleanSDem$Ethnicity <- factor(CleanSDem$EthID, levels = c( 
"1", "2", "3", "4", "5","6","7"),
labels = c('White/Caucasian','African American','Hispanic','N. American','Asian', 'Mixed' ,'Other'))

EthTabS <- table(CleanSDem$Ethnicity)
prop.table(EthTabS)

CleanSDem$Religion <- factor(CleanSDem$RelID, levels = c("0", 
"1", "2", "3", "4", "5","6","7","8","9"),
labels = c('Other','Catholic','Baptist','Other Christian','Buddhist', 'Muslim' ,'Jewish', 'None', 'Atheist', 'Agnostic'))

RelTabS <- table(CleanSDem$Religion)
prop.table(RelTabS)

##Study2

CleanIDem$Ethnicity <- factor(CleanIDem$EthID, levels = c( 
"1", "2", "3", "4", "5","6","7"),
labels = c('White/Caucasian','African American','Hispanic','N. American','Asian', 'Mixed' ,'Other'))

EthTabI <- table(CleanIDem$Ethnicity)
prop.table(EthTabI)

CleanIDem$Religion <- factor(CleanIDem$RelID, levels = c("0", 
"1", "2", "3", "4", "5","6","7","8","9"),
labels = c('Other','Catholic','Baptist','Other Christian','Buddhist', 'Muslim' ,'Jewish', 'None', 'Atheist', 'Agnostic'))

RelTabI <- table(CleanIDem$Religion)
prop.table(RelTabI)

##Study3

CleanCDem$Ethnicity <- factor(CleanCDem$EthID, levels = c( 
"1", "2", "3", "4", "5","6","7"),
labels = c('White/Caucasian','African American','Hispanic','N. American','Asian', 'Mixed' ,'Other'))

EthTabC <- table(CleanCDem$Ethnicity)
prop.table(EthTabC)

CleanCDem$Religion <- factor(CleanCDem$RelID, levels = c("0", 
"1", "2", "3", "4", "5","6","7","8","9"),
labels = c('Other','Catholic','Baptist','Other Christian','Buddhist', 'Muslim' ,'Jewish', 'None', 'Atheist', 'Agnostic'))

RelTabC <- table(CleanCDem$Religion)
prop.table(RelTabC)

##Study4

MoralDem$Ethnicity <- factor(MoralDem$EthID, levels = c( 
"1", "2", "3", "4", "5","6","7"),
labels = c('White/Caucasian','African American','Hispanic','N. American','Asian', 'Mixed' ,'Other'))

EthTabM <- table(MoralDem$Ethnicity)
prop.table(EthTabM)

MoralDem$Religion <- factor(MoralDem$RelID, levels = c("0", 
"1", "2", "3", "4", "5","6","7","8","9"),
labels = c('Other','Catholic','Baptist','Other Christian','Buddhist', 'Muslim' ,'Jewish', 'None', 'Atheist', 'Agnostic'))

RelTabM <- table(MoralDem$Religion)
prop.table(RelTabM)



###############################
######Overall Effects##########
###############################

     
#######################
##What predicts atheist error?
######################


AllAthTarg <- Overall[ which(Overall$TargNum == "1"
), ]

AllAthTarg$zPolitics <- scale(AllAthTarg$Politics, center=TRUE, scale=TRUE)

AllAthTarg$zBiG100 <- scale(AllAthTarg$BiG100, center=TRUE, scale=TRUE)




RelPol.lm <- glm(Error~ zBiG100, family=binomial, data=AllAthTarg)
summary(RelPol.lm)
exp(coef(RelPol.lm)) # exponentiated coefficients
exp(confint(RelPol.lm)) # 95% CI for exponentiated coefficients




###########################
###########################
##Feminist Big Game Pilot##
###########################




FemBig <- read.table("FemGame.csv", header=T, sep=",")
FemBig$CondNum <- ifelse(FemBig$Condition == "Feminist", 1, 0)
summary(FemBig)

describe.by(FemBig$Error, FemBig$Condition)


FemBig.lm <- brglm(Error~ CondNum, family=binomial, data=FemBig)
summary(FemBig.lm)
exp(coef(FemBig.lm)) # exponentiated coefficients
exp(confint(FemBig.lm)) # 95% CI for exponentiated coefficients



###########################
###########################
######India Pilot##########
###########################




FullInd <- read.table("IndiaMT.csv", header=T, sep=",")
summary(FullInd)

CleanInd <- FullInd[ which(FullInd$PrezCatch=='0'),]
CleanInd$TargNum <- ifelse(CleanInd$Target=="Atheist", 1, 0)

summary(CleanInd)


describe(CleanInd$Age)
describe(CleanInd$Politics)
describe(CleanInd$SES)
describe(CleanInd$BiG100)


table(FullInd$PrezCatch)

RelID <- table(CleanInd$RelID)
prop.table(RelID)

EthID <- table(CleanInd$EthID)
prop.table(EthID)

GendTab <- table(CleanInd$Gender)
prop.table(GendTab)


bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE,
    col=NULL, angle=NULL, density=NULL, main="Serial Killer, India",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=CleanInd, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)
     
     

AthTargInd.lm <- glm(Error~ TargNum, family=binomial, data=CleanInd)
summary(AthTargInd.lm)
exp(coef(AthTargInd.lm)) # exponentiated coefficients
exp(confint(AthTargInd.lm)) # 95% CI for exponentiated coefficients


describe.by(CleanInd$Error, CleanInd$Target)






###########################
######Single Deed Pilot####
###########################




CleanSingle1 <- read.table("Single1.csv", header=T, sep=",")

CleanSingle1$TargNum <- ifelse(CleanSingle1$Target=="Atheist", 1, 0)



summary(CleanSingle1)


describe(CleanSingle1$Age)

GendTab <- table(CleanSingle1$Sex)
prop.table(GendTab)

bargraph.CI(x.factor=Target, response=Error, group=NULL, split=FALSE,
    col=NULL, angle=NULL, density=NULL, main="Single1 Violation",
    lc=TRUE, uc=TRUE, legend=TRUE, ncol=1,
    bty='n', bg='white', 
    err.width= .0,
    err.col='black', err.lty=1,
    fun = function(x) mean(x, na.rm=TRUE),
    ci.fun= function(x) c(mean(x)-(1.96*se(x)), mean(x)+(1.96*se(x))),
    ylim=c(0, 1), xpd=FALSE, data=CleanSingle1, subset=NULL, 
     ylab='Proportion Conjunction Errors', cex.lab=1.5,)
     
     

AthTargSingle1.lm <- glm(Error~ TargNum, family=binomial, data=CleanSingle1)
summary(AthTargSingle1.lm)
exp(coef(AthTargSingle1.lm)) # exponentiated coefficients
exp(confint(AthTargSingle1.lm)) # 95% CI for exponentiated coefficients


describe.by(CleanSingle1$Error, CleanSingle1$Target)